<?php

namespace App\Domains\Artisan\Repositories;

use App\Core\Repository;
use App\Models\Artisan\Artisan as Model;

class ArtisanRepository extends Repository
{
    /**
     * 是否关闭缓存
     *
     * @var boolean
     */
    protected $cacheSkip = false;

    /**
     * 是否开启数据转化
     *
     * @var bool
     */
    protected $needTransform = false;

    /**
     * @var array
     */
    protected $fieldSearchable = [
        'id'         => '=',
        'created_at' => 'like',
    ];

    public function model()
    {
        return Model::class;
    }

    /**
     * 数据格式化
     *
     * @param mixed $result
     *
     * @return mixed
     */
    public function transform($model)
    {
        return $model->toArray();
    }

    /**
     * 查询条件
     *
     * @return void
     */
    public function withConditions(array $conditions = [])
    {
        if (isset($conditions['id'])) {
            $conditions['id'] = array_wrap($conditions['id']);
            $this->model = $this->model->whereIn('id', $conditions['id']);
        }

        if (isset($conditions['command'])) {
            $conditions['command'] = array_wrap($conditions['command']);
            $this->model = $this->model->whereIn('command', $conditions['command']);
        }

        if (isset($conditions['starttime'])) {
            $query->where('created_at', '>=', Carbon::parse($conditions['starttime']));
        }

        if (isset($conditions['endtime'])) {
            $query->where('created_at', '<=', Carbon::parse($conditions['endtime']));
        }

        return $this;
    }
}
