<?php

// Prefix: /api/companies
$router->group(['prefix' => 'companies', 'as' => 'companies'], function ($router) {

    // The controllers live in Domains/Company/Http/Controllers
    $router->get('/', ['as' => 'index', 'uses' => 'AccountController@index']);
    $router->get('/account/reset', ['as' => 'account.resetStep1', 'uses' => 'AccountController@resetStep1', 'middleware' => ['captcha']]);
    $router->post('/account/reset', ['as' => 'account.resetStep2', 'uses' => 'AccountController@resetStep2']);

    /**
     * 需要认证的接口
     */
    $router->group(['middleware' => ['companyAuth']], function ($router) {
        $router->post('/account/password_by_old', ['as' => 'account.passwordByOld', 'uses' => 'AccountController@password', 'middleware' => ['company_password']]);
        $router->post('/account/password_by_sms', ['as' => 'account.passwordBySms', 'uses' => 'AccountController@password', 'middleware' => ['verify_code']]);
        $router->post('/account/mobile', ['as' => 'account.mobile', 'uses' => 'AccountController@mobile', 'middleware' => ['verify_code']]);

        $router->get('/addresses/list', ['as' => 'addresses.list', 'uses' => 'AddressController@list']);
        $router->post('/addresses/create', ['as' => 'addresses.create', 'uses' => 'AddressController@create']);
        $router->post('/addresses/update/{id}', ['as' => 'addresses.update', 'uses' => 'AddressController@update']);
        $router->post('/addresses/destroy', ['as' => 'addresses.destroy', 'uses' => 'AddressController@destroy']);
        $router->post('/addresses/default/{id}', ['as' => 'addresses.default', 'uses' => 'AddressController@default']);

        $router->get('/bootstrap', ['as' => 'bootstrap', 'uses' => 'BootstrapController@index']);
        $router->get('/products', ['as' => 'products', 'uses' => 'BootstrapController@products']);
        $router->get('/cards', ['as' => 'cards', 'uses' => 'CardController@index']);

        $router->get('/orders/paginate', ['as' => 'orders/paginate', 'uses' => 'OrderController@paginate']);
        $router->get('/orders/show/{id}', ['as' => 'orders/show', 'uses' => 'OrderController@show']);
        $router->get('/orders/cards/{id}', ['as' => 'orders/cards', 'uses' => 'OrderController@cards']);
        $router->post('/orders/store', ['as' => 'orders/store', 'uses' => 'OrderController@store']);
        $router->post('/orders/cancel', ['as' => 'orders/cancel', 'uses' => 'OrderController@cancel']);
        $router->post('/orders/received', ['as' => 'orders/received', 'uses' => 'OrderController@received']);

        $router->post('/orders/store-added', ['as' => 'orders/storeAdded', 'uses' => 'OrderController@storeAdded']);
    });
});
