<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreatePermissionTables extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        if (!Schema::hasTable('permissions')) {
            Schema::create('permissions', function (Blueprint $table) {
                $table->increments('id');
                $table->string('name', 32)->default('')->comment('标识');
                $table->string('title', 32)->default('')->comment('名称');
                $table->string('description')->default('')->comment('描述');
                $table->string('path')->default('')->comment('路径');
                $table->string('icon')->default('')->comment('图标');
                $table->tinyInteger('type')->unsigned()->default(0)->comment('类型 0:页面 1:接口');
                $table->tinyInteger('status')->unsigned()->default(1)->comment('状态 0:关闭 1:启用');
                $table->tinyInteger('open')->unsigned()->default(0)->comment('打开方式: 0:iframe方式 1打开新窗口 2:弹出窗口 3:vue组件');
                $table->mediumInteger('height')->unsigned()->default(0)->comment('页面高度');
                $table->mediumInteger('width')->unsigned()->default(0)->comment('页面宽度');
                $table->tinyInteger('displayorder')->unsigned()->default(0)->comment('排序');
                $table->nestedset();
                $table->timestamps();

                $table->comment('权限表');
            });
        }

        if (!Schema::hasTable('roles')) {
            Schema::create('roles', function (Blueprint $table) {
                $table->increments('id');
                $table->string('name', 32)->default('')->comment('标识');
                $table->string('remark')->default('')->comment('备注');
                $table->nestedset();
                $table->timestamps();
                $table->unique(['name']);

                $table->comment('角色表');
            });
        }

        if (!Schema::hasTable('account_has_roles')) {
            Schema::create('account_has_roles', function (Blueprint $table) use ($tableNames) {
                $table->unsignedInteger('role_id');
                $table->unsignedInteger('account_id');
                $table->primary(['role_id', 'account_id']);

                $table->comment('账号角色关联表');
            });
        }

        if (!Schema::hasTable('role_has_permissions')) {
            Schema::create('role_has_permissions', function (Blueprint $table) use ($tableNames) {
                $table->unsignedInteger('permission_id');
                $table->unsignedInteger('role_id');
                $table->primary(['permission_id', 'role_id']);

                $table->comment('角色权限关联表');
            });
        }
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::drop('role_has_permissions');
        Schema::drop('account_has_roles');
        Schema::drop('roles');
        Schema::drop('permissions');
    }
}
