<?php

namespace App\Domains\Virtual\Repositories;

use App\Core\Repository;
use App\Models\Virtual\Company as Model;

class CompanyRepository extends Repository
{
    /**
     * 是否关闭缓存
     *
     * @var boolean
     */
    protected $cacheSkip = false;

    /**
     * 是否开启数据转化
     *
     * @var bool
     */
    protected $needTransform = false;

    /**
     * @var array
     */
    protected $fieldSearchable = [
        'id'         => '=',
        // 'created_at' => 'like',
        'name' => 'like',
        'accounts.username' => 'like',
    ];

    public function model()
    {
        return Model::class;
    }

    /**
     * 数据格式化
     *
     * @param mixed $result
     *
     * @return mixed
     */
    public function transform($model)
    {
        return $model->toArray();
    }

    /**
     * 查询条件
     *
     * @return void
     */
    public function withConditions(array $conditions = [])
    {
        if (isset($conditions['id'])) {
            $conditions['id'] = array_wrap($conditions['id']);
            $this->model = $this->model->whereIn('id', $conditions['id']);
        }

        if (!empty($conditions['name'])) {
            $this->model = $this->model->where('name', 'like', "%{$conditions['name']}%");
        }

        if (isset($conditions['status'])) {
            $this->model = $this->model->where('status', $conditions['status']);
        }

        return $this;
    }
}
