<?php

namespace App\Domains\Virtual\Repositories;

use Carbon\Carbon;
use App\Core\Repository;
use App\Models\Virtual\FlowPoolSetting as Model;

class FlowPoolSettingRepository extends Repository
{
    /**
     * 是否关闭缓存
     *
     * @var boolean
     */
    protected $cacheSkip = false;

    /**
     * 是否开启数据转化
     *
     * @var bool
     */
    protected $needTransform = false;

    /**
     * @var array
     */
    protected $fieldSearchable = [
        'id'         => '=',
        'created_at' => 'like',
    ];

    public function model()
    {
        return Model::class;
    }

    /**
     * 数据格式化
     *
     * @param mixed $result
     *
     * @return mixed
     */
    public function transform($model)
    {
        return $model->toArray();
    }

    /**
     * 查询条件
     *
     * @return void
     */
    public function withConditions(array $conditions = [])
    {
        if (isset($conditions['id'])) {
            $conditions['id'] = array_wrap($conditions['id']);
            $this->model = $this->model->whereIn('id', $conditions['id']);
        }

        if (isset($conditions['pool_id'])) {
            $conditions['pool_id'] = array_wrap($conditions['pool_id']);
            $this->model = $this->model->whereIn('pool_id', $conditions['pool_id']);
        }

        if (isset($conditions['month'])) {
            $time = Carbon::parse($conditions['month'])->format('Y-m-d H:i:s');
            $this->model = $this->model->where(function ($subQuery) use ($time) {
                $subQuery->where('start_at', '<=', $time)->where('end_at', '>=', $time);
            });
        }

        return $this;
    }
}
