<?php

namespace App\Domains\Virtual\Repositories;

use App\Core\Repository;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Log;
use App\Models\Virtual\Order as Model;
use App\Domains\Virtual\Services\CommonService;

class OrderRepository extends Repository
{
    /**
     * 是否关闭缓存
     *
     * @var boolean
     */
    protected $cacheSkip = false;

    /**
     * 是否开启数据转化
     *
     * @var bool
     */
    protected $needTransform = false;

    /**
     * @var array
     */
    protected $fieldSearchable = [
        'sn'           => 'like',
        'package.name' => 'like',
    ];

    public function model()
    {
        return Model::class;
    }

    /**
     * 数据格式化
     *
     * @param mixed $result
     *
     * @return mixed
     */
    public function transform($model)
    {
        return $model;
    }

    /**
     * 查询条件
     *
     * @return void
     */
    public function withConditions(array $conditions = [])
    {
        $this->model = $this->model->where(function ($query) use ($conditions) {
            if (isset($conditions['id'])) {
                $conditions['id'] = array_wrap($conditions['id']);
                $query->whereIn('id', $conditions['id']);
            }

            if (isset($conditions['source'])) {
                $query->where('source', $conditions['source']);
            }

            if (isset($conditions['type'])) {
                $conditions['type'] = array_wrap($conditions['type']);
                $query->whereIn('type', $conditions['type']);
            }

            if (isset($conditions['company_id'])) {
                $conditions['company_id'] = array_wrap($conditions['company_id']);
                $query->whereIn('company_id', $conditions['company_id']);
            }

            if (!empty($conditions['sn'])) {
                $query->where('sn', 'like', "%{$conditions['sn']}%");
            }

            if (!empty($conditions['transaction_no'])) {
                $query->where('transaction_no', 'like', "%{$conditions['transaction_no']}%");
            }

            if (isset($conditions['order_status'])) {
                $query->where('order_status', $conditions['order_status']);
            }

            if (isset($conditions['transaction_status'])) {
                $query->where('transaction_status', $conditions['transaction_status']);
            }

            if (isset($conditions['carrier_operator'])) {
                $query->whereHas('package', function ($relation) use ($conditions) {
                    $relation->withTrashed()->where('carrier_operator', $conditions['carrier_operator']);
                });
            }

            if (isset($conditions['pay_channel'])) {
                $query->where('pay_channel', $conditions['pay_channel']);
            }

            if (!empty($conditions['company_name'])) {
                $query->whereHas('company', function ($relation) use ($conditions) {
                    $relation->withTrashed()->where('name', $conditions['company_name']);
                });
            }

            if (!empty($conditions['package_name'])) {
                $query->whereHas('package', function ($relation) use ($conditions) {
                    $relation->withTrashed()->where('name', $conditions['package_name']);
                });
            }

            if (isset($conditions['sim'])) {
                $conditions['sim'] = array_wrap($conditions['sim']);
                $query->whereHas('cards', function ($relation) use ($conditions) {
                    $relation->whereIn('sim', $conditions['sim']);
                });
            }

            if (isset($conditions['starttime'])) {
                $query->where('order_at', '>=', Carbon::parse($conditions['starttime']));
            }

            if (isset($conditions['endtime'])) {
                $query->where('order_at', '<=', Carbon::parse($conditions['endtime']));
            }
        });

        return $this;
    }
}
