<?php

namespace App\Models\Virtual;

use App\Core\Model;
use Illuminate\Auth\Authenticatable;
use Tymon\JWTAuth\Contracts\JWTSubject;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Contracts\Auth\Authenticatable as AuthenticatableContract;

/**
 * App\Models\Virtual\CompanyAccount
 *
 * @property int $id 自增ID
 * @property int $company_id 企业ID
 * @property string $nickname 昵称
 * @property string|null $mobile 手机号
 * @property string $username 登录名
 * @property string $password 密码
 * @property string $salt 盐
 * @property int $status 状态 0未激活 1正常 2禁用
 * @property \Illuminate\Support\Carbon|null $created_at
 * @property \Illuminate\Support\Carbon|null $updated_at
 * @property string|null $deleted_at
 * @method static bool|null forceDelete()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount newModelQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount newQuery()
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\CompanyAccount onlyTrashed()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount query()
 * @method static bool|null restore()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereCompanyId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereCreatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereDeletedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereMobile($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereNickname($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount wherePassword($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereSalt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereStatus($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereUpdatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\CompanyAccount whereUsername($value)
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\CompanyAccount withTrashed()
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\CompanyAccount withoutTrashed()
 * @mixin \Eloquent
 */
class CompanyAccount extends Model implements AuthenticatableContract, JWTSubject
{
    use SoftDeletes, Authenticatable;

    protected $table = 'virtual_company_accounts';

    protected $fillable = ['id', 'company_id' , 'nickname', 'username', 'mobile', 'password', 'salt', 'status'];

    /**
     * Get the hidden attributes for the model.
     *
     * @return array
     */
    public function getHidden()
    {
        return ['password', 'salt', 'deleted_at'];
    }

    /**
     * Get the identifier that will be stored in the subject claim of the JWT.
     *
     * @return mixed
     */
    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Return a key value array, containing any custom claims to be added to the JWT.
     *
     * @return array
     */
    public function getJWTCustomClaims()
    {
        return [];
    }
}
