<?php

namespace App\Models\Virtual;

use App\Core\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

/**
 * App\Models\Virtual\Product
 *
 * @property int $id 自增ID
 * @property string $sn 产品编码
 * @property string $name 产品名称
 * @property int $company_id 企业ID
 * @property int $package_id 套餐ID
 * @property int $base_price 基础价格
 * @property int $renewal_price 续费价格
 * @property string|null $remark 备注
 * @property \Illuminate\Support\Carbon|null $created_at
 * @property \Illuminate\Support\Carbon|null $updated_at
 * @property string|null $deleted_at
 * @property-read \App\Models\Virtual\Company $company
 * @property-read \App\Models\Virtual\Package $package
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product newModelQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product newQuery()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product query()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereBasePrice($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereCompanyId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereCreatedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereDeletedAt($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereName($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product wherePackageId($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereRemark($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereRenewalPrice($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereSn($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereUpdatedAt($value)
 * @mixin \Eloquent
 * @property int $type 订单类型（0:基础订单 1:套餐续费 2：续费包 3:加油包 4:可选包 5:附加包）
 * @property int $price 价格
 * @property int $flowed 是否是后向流量池套餐 0:否 1:是
 * @property int $status 状态 0:正常 1:禁用
 * @method static bool|null forceDelete()
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\Product onlyTrashed()
 * @method static bool|null restore()
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereFlowed($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product wherePrice($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereStatus($value)
 * @method static \Illuminate\Database\Eloquent\Builder|\App\Models\Virtual\Product whereType($value)
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\Product withTrashed()
 * @method static \Illuminate\Database\Query\Builder|\App\Models\Virtual\Product withoutTrashed()
 */
class Product extends Model
{
    use SoftDeletes;

    protected $table = 'virtual_products';

    public function company()
    {
        return $this->belongsTo(Company::class, 'company_id', 'id');
    }

    public function package()
    {
        return $this->belongsTo(Package::class, 'package_id', 'id');
    }
}
