<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateRealOrdersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        if (Schema::hasTable('real_orders')) {
            return;
        }

        Schema::create('real_orders', function (Blueprint $table) {
            $table->increments('id')->comment('订单ID');
            $table->string('sn', 64)->comment('订单编号');
            $table->tinyInteger('type')->unsigned()->default(0)->comment('订单类型（0:基础订单 1:套餐续费 2：续费包 3:加油包 4:可选包 5:附加包）');
            $table->integer('company_id')->unsigned()->default(0)->comment("企业ID");
            $table->integer('package_id')->unsigned()->default(0)->comment("套餐ID");
            $table->string('transaction_no', 64)->comment('交易流水号');
            $table->string('pay_channel', 20)->default('')->comment('支付频道');
            $table->integer('unit_price')->unsigned()->default(0)->comment('单价');
            $table->integer('counts')->unsigned()->default(0)->comment('数量');
            $table->integer('total_price')->unsigned()->default(0)->comment('总价');
            $table->timestamp('order_at')->nullable()->comment('下单时间');
            $table->string('address')->default('')->comment('收货地址');
            $table->string('contacts')->default('')->comment('联系人');
            $table->string('mobile')->default('')->comment('电话');
            $table->text('logistics_remark')->nullable()->comment('物流备注');
            $table->text('remark')->nullable()->comment('订单备注');
            $table->timestamps();
            $table->softDeletes();

            $table->unique(['sn', 'deleted_at']);
            $table->index('type');
            $table->index(['company_id', 'package_id']);
            $table->index('order_at');

            $table->comment('RD订单');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('real_orders');
    }
}
