<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateVirtualProductsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        if (Schema::hasTable('virtual_products')) {
            return;
        }

        Schema::create('virtual_products', function (Blueprint $table) {
            $table->increments('id')->comment('自增ID');
            $table->tinyInteger('type')->unsigned()->default(0)->comment('订单类型（0:基础订单 1:套餐续费 2：续费包 3:加油包 4:可选包 5:附加包）');
            $table->string('sn', 32)->comment('产品编码');
            $table->string('name', 32)->comment('产品名称');
            $table->integer('company_id')->unsigned()->default(0)->comment('企业ID');
            $table->integer('package_id')->unsigned()->default(0)->comment('套餐ID');
            $table->integer('price')->unsigned()->default(0)->comment('价格');
            $table->integer('renew_price')->unsigned()->default(0)->comment('续费价格');
            $table->text('remark')->nullable()->comment('备注');
            $table->tinyInteger('status')->unsigned()->default(0)->comment('状态 0:正常 1:禁用');
            $table->timestamps();
            $table->softDeletes();

            $table->unique(['sn', 'deleted_at']);

            $table->comment('VD企业定价表');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('virtual_products');
    }
}
