<?php

use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateFlowPoolTables extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        if (!Schema::hasTable('real_flow_pools')) {
            Schema::create('real_flow_pools', function (Blueprint $table) {
                $table->increments('id')->comment('自增ID');
                $table->string('sn', 32)->default('')->comment('编号');
                $table->integer('company_id')->unsigned()->default(0)->comment('关联企业ID');
                $table->string('name', 32)->unsigned()->default(0)->comment('名称');
                $table->integer('flows')->default(255)->comment('流量值 -1不限流量 单位MB');
                $table->tinyInteger('carrier_operator')->unsigned()->default(255)->comment('运营商(0:联通 1:移动 2:电信)');
                $table->tinyInteger('shared')->unsigned()->default(0)->comment('共享类型 0:未知 1同流量横向共享 2基础流量纵向共享 3纵向共享');
                $table->text('package_ids')->nullable()->comment('包含套餐');
                $table->timestamps();
                $table->softDeletes();

                $table->unique(['sn', 'deleted_at']);

                $table->comment('RD流量池');
            });
        }

        if (!Schema::hasTable('virtual_flow_pools')) {
            Schema::create('virtual_flow_pools', function (Blueprint $table) {
                $table->increments('id')->comment('自增ID');
                $table->string('sn', 32)->default('')->comment('编号');
                $table->integer('company_id')->unsigned()->default(0)->comment('关联企业ID');
                $table->string('name', 32)->unsigned()->default(0)->comment('名称');
                $table->integer('flows')->default(-1)->comment('流量值 -1不限流量 单位MB');
                $table->tinyInteger('carrier_operator')->unsigned()->default(255)->comment('运营商(0:联通 1:移动 2:电信)');
                $table->tinyInteger('shared')->unsigned()->default(0)->comment('共享类型 0:未知 1纵向共享 2横向共享');
                $table->text('package_ids')->nullable()->comment('包含套餐');
                $table->text('real_pool_ids')->nullable()->comment('RD流量池ID');
                $table->text('remark')->nullable()->comment('流量池备注');
                $table->timestamp('start_at')->nullable()->comment('开始时间');
                $table->timestamp('end_at')->nullable()->comment('结束时间');
                $table->timestamps();
                $table->softDeletes();

                $table->unique(['sn', 'deleted_at']);

                $table->comment('VD流量池');
            });
        }

        if (!Schema::hasTable('virtual_flow_pool_settings')) {
            Schema::create('virtual_flow_pool_settings', function (Blueprint $table) {
                $table->increments('id')->comment('自增ID');
                $table->integer('pool_id')->unsigned()->default(0)->comment('流量池ID');
                $table->text('minimum_settings')->nullable()->comment('套餐保底配置');
                $table->integer('gradient_price')->unsigned()->default(0)->comment('梯度单价');
                $table->decimal('gradient', 10, 2)->unsigned()->default(0)->comment('梯度');
                $table->tinyInteger('gradient_unit')->unsigned()->default(0)->comment('梯度单位 0:M 1:G');
                $table->timestamp('start_at')->nullable()->comment('开始时间');
                $table->timestamp('end_at')->nullable()->comment('结束时间');
                $table->timestamps();
                $table->softDeletes();

                $table->index('pool_id');

                $table->comment('VD流量池定价');
            });
        }

        if (!Schema::hasTable('virtual_flow_pool_data')) {
            Schema::create('virtual_flow_pool_data', function (Blueprint $table) {
                $table->increments('id')->comment('自增ID');
                $table->integer('pool_id')->unsigned()->default(0)->comment('流量池ID');
                $table->integer('month')->unsigned()->default(0)->comment('月份');
                $table->decimal('total_flows', 10, 2)->unsigned()->default(0)->comment('总使用流量 单位MB');
                $table->text('settings')->nullable()->comment('配置');
                $table->timestamps();

                $table->index(['month', 'pool_id']);

                $table->comment('VD流量池数据设置');
            });
        }

        if (!Schema::hasTable('virtual_flow_pool_months')) {
            Schema::create('virtual_flow_pool_months', function (Blueprint $table) {
                $table->increments('id')->comment('订单ID');
                $table->integer('month')->unsigned()->default(0)->comment('月份');
                $table->bigInteger('sim')->unsigned()->default(0)->comment('SIM号');
                $table->integer('package_id')->unsigned()->default(0)->comment('套餐ID');
                $table->integer('pool_id')->unsigned()->default(0)->comment('流量池ID');
                $table->decimal('mebibyte', 10, 2)->unsigned()->default(0)->comment('使用流量 单位MB');
                $table->comment('VD卡月流量');

                $table->partition('month', 'list');
            });
        }

        DB::unprepared(File::get(__DIR__ . '/create_flow_pool_func.pgsql'));
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('virtual_flow_pool_months');
        Schema::dropIfExists('virtual_flow_pool_data');
        Schema::dropIfExists('virtual_flow_pool_settings');
        Schema::dropIfExists('virtual_flow_pools');
        Schema::dropIfExists('real_flow_pools');
    }
}
