import { mapGetters } from 'vuex';
import { objectDot } from 'service/util';
import default_head from 'images/head.png';
import { getToken } from 'service/auth';

export default {
  data() {
    return {
      CONFIG: window.CONFIG,
      default_head,
      page_loading: { // 加载中
        show: false,
        msg: ''
      },
      none_obj: { // 无数据
        show: false,
        msg: '未找到相关信息'
      },
      disableDate: {
        disabledDate(date) {
          return date && date.valueOf() > Date.now();
        }
      },
      disableMonth: {
        disabledDate(date) {
          let now = new Date();
          let ym = this.moment().set({
            'year': now.getFullYear(),
            'month': now.getMonth()
          });
          return date && date.valueOf() > ym;
        }
      },
      datePickerOptionsMonth: {
        shortcuts: [
          {
            text: '本月',
            value: () => {
              return [
                this.moment().startOf('month').format('YYYY-MM-DD'),
                this.moment().endOf('month').format('YYYY-MM-DD')
              ];
            }
          },
          {
            text: '前一个月',
            value: () => {
              return [
                this.moment().subtract('1', 'months').startOf('month').format('YYYY-MM-DD'),
                this.moment().subtract('1', 'months').endOf('month').format('YYYY-MM-DD')
              ];
            }
          },
          {
            text: '前两个月',
            value: () => {
              return [
                this.moment().subtract('2', 'months').startOf('month').format('YYYY-MM-DD'),
                this.moment().subtract('2', 'months').endOf('month').format('YYYY-MM-DD')
              ];
            }
          }
        ]
      }
    };
  },
  computed: {
    token: () => {
      return getToken();
    },
    ...mapGetters(['apps_info', 'left_menu', 'top_menu', 'permissions_array', 'permissions_object', 'account', 'page_nodes', 'tagnavs', 'cache_page', 'breadcrumb'])
  },
  methods: {
    // 加载中
    isShowLoading(bool = false) {
      this.page_loading.show = bool;
    },

    // 无数据
    isShowNoneData(bool = false) {
      this.none_obj.show = bool;
    },

    showInfo(content = '') {
      this.$Modal.info({
        title: '提示',
        content
      });
    },

    /**
     * [isRoot 内置超级管理员判断]
     * @return {Boolean} [description]
     */
    isRoot() {
      return !!((this.account && this.account.username == 'root'));
    },

    /**
     * [searchDataHandle 处理列表搜索字段]
     * @param  {[type]} search_data [接口search项字段]
     * @param  {[type]} options      [接口search项以外的字段]
     * @param  {[type]} page        [页码相关字段]
     * @return {[type]}             [description]
     */
    searchDataHandle(search_data, page = {}, options = {}) {
      let data = {};
      let search = [];

      let init_options = {
        orderBy: 'updated_at',
        sortedBy: 'desc'
      };

      let init_page = {
        page: 1,
        limit: 20
      };

      init_options = Object.assign({}, init_options, options);
      init_page = Object.assign({}, init_page, page);

      // 页码
      for (let k in init_page) {
        data[k] = init_page[k];
      }

      // search项以外的字段
      Object.assign(data, this.parseParams(init_options));

      // search 项
      search_data = objectDot(search_data);

      for (let k in search_data) {
        search.push([k, search_data[k]].join(':'));
      }

      if (search.length) {
        data.search = search.join(';');
      }
      return data;
    },
    // 格式化参数
    parseParams(params) {
      let obj = {};
      for (let k in params) {
        if (k == 'time') {
          if (params.time && params.time[0] && params.time[1]) {
            Object.assign(obj, this.parseTime(params.time));
          }
        } else {
          if (params[k] !== '' && params[k] !== undefined && params[k] !== null) {
            obj[k] = params[k];
          }
        }
      }
      return obj;
    },
    // 搜索的时间字段转化为starttime, endtime
    parseTime(time) {
      return {
        starttime: this.moment(time[0]).format('YYYY-MM-DD') + ' 00:00:00',
        endtime: this.moment(time[1]).format('YYYY-MM-DD') + ' 23:59:59'
      };
    },

    // 导出excel表格
    downloadExcel(tHeader, data, title) {
      require.ensure([], () => {
        const {
          export_json_to_excel
        } = require('lib/xls/Export2Excel');
        export_json_to_excel(tHeader, data, title);
      });
    },
    formatJson(filterVal, jsonData) {
      if (Object.prototype.toString.call(filterVal) == '[object Array]') {
        if (Object.prototype.toString.call(jsonData) == '[object Array]') {
          return jsonData.map(v => filterVal.map(j => v[j]));
        } else if (Object.prototype.toString.call(jsonData) == '[object Object]') {
          return Object.keys(jsonData).map(v => filterVal.map(j => jsonData[v][j]));
        } else {
          throw new Error('jsonData请传入数组或对象');
        }
      } else {
        throw new Error('filterVal请传入数组');
      }
    },
    customInfoByExcel(h, data, tHeader, filterVal) {
      /**
       * [customInfoByExcel 信息提示带有表格下载]
       * @param  {[type]} h         [render 函数]
       * @param  {[type]} data      [表格数据]
       * @param  {[type]} tHeader   [表格标题]
       * @param  {[type]} filterVal [过滤数据]
       * @return {[type]}           [description]
       */
      return h('p', {
        style: {
          fontSize: '14px',
          marginTop: '15px'
        }
      },
      [
        h('span', data.message + ' 请点击下载：'),
        h('span', {
          domProps: {
            innerHTML: '导入失败.xls'
          },
          class: ['primary-color', 'c-p'],
          on: {
            click: () => {
              this.downloadExcel(tHeader, this.formatJson(filterVal, data.result), '导入失败');
            }
          }
        })
      ]);
    },
    exportExcelInfo(h, data) {
      /**
       * [customInfoByExcel 信息提示带有表格下载]
       * @param  {[type]} h         [render 函数]
       * @param  {[type]} data      []
       * @return {[type]}           [description]
       */

      return h('p', {
        style: {
          fontSize: '14px',
          marginTop: '15px'
        }
      },
      [
        h('span', data.message + ' 请点击下载：'),
        h('span', {
          domProps: {
            innerHTML: '导入失败.xls'
          },
          class: ['primary-color', 'c-p'],
          on: {
            click: () => {
              if (data.url !== '') {
                window.open(data.url);
              } else {
                this.$Message.info('无数据可下载');
              }
            }
          }
        })
      ]
      );
    },
    downloadFile(url) {
      const link = document.createElement('a');
      link.href = url;
      link.download = url.substring(url.lastIndexOf('/') + 1);
      document.body.appendChild(link);
      link.click();
      window.URL.revokeObjectURL(url);
    }
  }
};
