/**
 * [removeAllEmpty 去除所有空字符串]
 * @param  {[type]} value [字符串]
 * @return {[type]}       [返回新字符串]
 */
export function removeAllEmpty(value) {
  return value.replace(/\s/g, '');
}

/**
 * [isPhone 手机号校验]
 * @param  {[type]}  value [手机号码]
 * @return {Boolean}       [返回布尔值]
 */
export function isPhone(value) {
  value = String(value).trim(); // 去除首尾空格
  return value.length === 11 && /^((13|14|15|16|17|18|19)[0-9]{1}\d{8})$/.test(value);
}

/**
 * [isTel 电话号码校验]
 * @param  {[type]}  value [电话]
 * @return {Boolean}       [返回布尔值]
 */
export function isTel(value) {
  value = value.toString().trim();
  return /(^[0-9]{3,4}-[0-9]{7}$)|(^((13|14|15|16|17|18|19)[0-9]{1}\d{8})$)/.test(value);
}

/**
 * [isCarNum 车牌号校验]
 * @param  {[type]}  value [车牌号]
 * @return {Boolean}       [返回布尔值]
 */
export function isCarNo(value) {
  value = value.toUpperCase().trim();
  return value.length === 7 && /^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}[A-Z0-9]{4}[A-Z0-9挂学警港澳]{1}$/.test(value);
}

/**
 * [keywordFilter 只能输入汉字、字母、数字或下划线]
 * @param  {[String]} value [字符串]
 * @return {[type]}       [返回新的字符串]
 */
export function keywordFilter(value) {
  return /^[a-zA-Z0-9_\u4e00-\u9fa5]*$/.test(value);
}

/**
 * [isWebUrl 判断是否是链接地址]
 * @param  {[String]}  value [链接]
 * @return {Boolean}
 */
export function isWebUrl(value) {
  value = value.trim();
  return /^([hH][tT]{2}[pP]:\/\/|[hH][tT]{2}[pP][sS]:\/\/)(([A-Za-z0-9-~]+)\.)+([A-Za-z0-9-~/])+$/.test(value);
}

/**
 * [isFloat 判断是否为浮点数]
 * @param  {[type]}  value [description]
 * @return {Boolean}       [description]
 */
export function isFloat(value) {
  value = value.toString().trim();
  return /^(-?\d+)(\.\d+)?$/.test(value);
}

/**
 * [isIntNum 只能正整数]
 * @param  {[String]} value [字符串]
 * @return {[type]}       [返回新的字符串]
 */
export function isIntNum(value) {
  return /^\+?[1-9][0-9]*$/.test(value);
}

/**
 * [isPositiveInteger 判断是否大于等于0的整数]
 * @param  {[type]}  value [description]
 * @return {Boolean}       [description]
 */
export function isPositiveInteger(value) {
  value = value.toString().trim();
  return /^\d+$/.test(value);
}

/**
 * [isIe 判断浏览器是否是ie内核]
 * @return {Boolean} [description]
 */
export function isIe() {
  if (!!window.ActiveXObject || 'ActiveXObject' in window) {
    return true;
  }
  return false;
}

/**
 * [isImage 判断是否是图片]
 * @param  {[type]}  name [图片地址]
 * @return {Boolean}      [description]
 */
export function isImage(name) {
  return /(jpe?g|png|gif|bmp)$/i.test(name);
}

/**
 * [isPsw 验证此站点密码的合法性-长度在6-18之间，只能包含字母、数字和下划线]
 * @param  {[type]}  value [description]
 * @return {Boolean}       [description]
 */
export function isPsw(value) {
  return /^[a-zA-Z0-9_]{6,18}$/.test(value);
}

/**
 * [isUserName 用户名合法性判断-以字母开头，长度在4-32之间，只能包含字母、数字和下划线]
 * @param  {[type]}  value [description]
 * @return {Boolean}       [description]
 */
export function isUserName(value) {
  return /^[a-zA-Z][a-zA-Z0-9]{3,31}$/.test(value);
}
