export default {
  name: 'RealSync',
  components: {
    UiEdit: resolve => require(['views/artisan/real-sync/edit'], resolve),
    UiRefund: resolve => require(['views/artisan/real-sync/refund'], resolve),
    UiCancelled: resolve => require(['views/artisan/real-sync/cancelled'], resolve)
  },
  data() {
    return {
      commands: {
        'real:sync-added-order': '同步RD企业订单数据',
        'real:sync-company': '同步RD企业数据',
        'real:sync-mongo': '同步卡基础信息数据',
        'real:sync-order': '同步RD基础订单数据',
        'real:sync-package': '同步RD套餐数据',
        'real:sync-refund': '同步RD退货数据',
        'real:sync-cancelled': '同步RD注销数据'
      },
      options: {
        command: null,
        time: []
      },
      list_data: null,
      editObj: {
        show: false
      },
      refundObj: {
        show: false
      },
      cancelledObj: {
        show: false
      },
      search: {
        show: false
      },
      table_titles: [
        {
          title: 'ID',
          key: 'id',
          width: 80
        },
        {
          title: '名称',
          key: 'command_name',
          width: 300
        },
        {
          title: '命令',
          key: 'command'
        },
        {
          title: '参数',
          key: 'parameters'
        },
        {
          title: '执行时间',
          key: 'created_at',
          width: 170
        }
      ]
    };
  },
  created() {
    this.index(1);
  },
  methods: {
    /**
     * [index 列表]
     * @param  {Number} page [description]
     * @return {[type]}      [description]
     */
    index(page = 1) {
      let params = this.searchDataHandle({}, { page }, this.options);

      params.command = params.command ? params.command : Object.keys(this.commands);

      this.isShowLoading(true);

      service.get('/api/artisan', { params }).then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.list_data = res.data;
        }
      }).catch(() => {
        this.isShowLoading(false);
      });
    },

    /**
     * [openEdit 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openEdit(bool) {
      this.editObj = {
        show: bool
      };
    },

    /**
     * [openRefund 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openRefund(bool) {
      this.refundObj = {
        show: bool
      };
    },

    /**
     * [openCancelled 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openCancelled(bool) {
      this.cancelledObj = {
        show: bool
      };
    },

    /**
     * [request 刷新]
     * @return {[type]} [description]
     */
    request() {
      const result = this.list_data;
      let page = result.current_page;

      if (this.list_data.data.length == 1) {
        page = this.returnPage(result.total, result.current_page, result.per_page);
      }

      this.index(page);
    },

    resetSearch() {
      this.options.command = null;
      this.options.time = [];
      this.index(1);
    }
  }
};
