import * as API from 'api/base/accounts';
import { isPsw } from 'validate';

export default{
  props: {
    show: {
      type: Boolean,
      default: false
    }
  },
  watch: {
    show(bool) {
      this.my_show = bool;
    }
  },
  data() {
    return {
      my_show: false,
      loading: false,
      params: {
        password: '',
        current_password: '',
        confirm_password: ''
      }
    };
  },
  methods: {
    ok() {
      if (!this.params.current_password) {
        this.$Message.info('请填写密码');
        return;
      }

      if (!isPsw(this.params.current_password)) {
        this.$Message.info('密码长度在6-18之间，只能包含字母、数字和下划线');
        return;
      }

      if (!this.params.confirm_password) {
        this.$Message.info('请填写确认密码');
        return;
      }

      if (this.params.current_password != this.params.confirm_password) {
        this.$Message.info('密码与确认密码填写不一致');
        return;
      }

      this.params.password = md5(this.params.current_password);

      let data = new FormData();

      for (let k in this.params) {
        if (k != 'current_password' || k != 'confirm_password') {
          if (this.params[k]) {
            data.append(k, this.params[k]);
          }
        }
      }

      API.update(data, this.account.id).then(res => {
        this.loading = false;
        if (res.code == 0) {
          this.$Message.success('密码修改成功');
          this.my_show = false;
        }
      }).catch(err => {
        this.loading = false;
      });
    },

    visibleChange(bool) {
      if (!bool) {
        this.$emit('update:show', false);
        for (let k in this.params) {
          this.params[k] = '';
        }
      }
    }
  }
};
