import * as API from 'api/base/accounts';

export default{
  name: 'Accounts',
  components: {
    UiEdit: resolve => require(['views/user/accounts/edit'], resolve),
    UiDetail: resolve => require(['views/user/accounts/detail'], resolve)
  },
  data() {
    return {
      params: {
        username: '',
        nickname: '',
        status: ''
      },
      list_data: null,
      editObj: {
        show: false,
        data: null
      },
      detailObj: {
        show: false,
        data: null
      },
      search: {
        show: false
      },
      table_titles: [
        {
          title: '用户名',
          key: 'username'
        },
        {
          title: '权限组',
          key: '',
          render: (h, { row, column, index }) => {
            if (row.roles && row.roles.length) {
              return h('span', row.roles[0].name);
            }
          }
        },
        {
          title: '姓名',
          key: 'nickname'
        },
        {
          title: '状态',
          key: 'status',
          render: (h, { row, column, index }) => {
            return h('Tag', {
              props: {
                color: row.status == 1 ? 'blue' : 'default'
              }
            }, row.status == 1 ? '启用' : '禁用');
          }
        },
        {
          title: '创建时间',
          key: 'created_at',
          width: 170
        },
        {
          title: '操作',
          key: 'action',
          width: 300,
          render: (h, { row, column, index }) => {
            let html = [];

            if (this.haveJurisdiction('show')) {
              html.push(h('Button', {
                props: {
                  type: 'success',
                  size: 'small',
                  disabled: false,
                  icon: 'md-eye'
                },
                class: ['btn'],
                on: {
                  click: (event) => {
                    this.detailObj = {
                      show: true,
                      data: row
                    };
                  }
                }
              }, '查看'));
            }

            if (this.haveJurisdiction('update')) {
              html.push(h('Button', {
                props: {
                  type: 'primary',
                  size: 'small',
                  disabled: false,
                  icon: 'md-create'
                },
                class: ['btn'],
                on: {
                  click: (event) => {
                    this.openEdit(true, row);
                  }
                }
              }, '编辑'));
            }

            if (this.haveJurisdiction('destroy')) {
              html.push(h('Button', {
                props: {
                  type: 'error',
                  size: 'small',
                  disabled: false,
                  icon: 'md-trash'
                },
                class: ['btn'],
                on: {
                  click: () => {
                    this.$Modal.confirm({
                      title: '提示',
                      content: '删除后账号不可使用，请谨慎操作',
                      onOk: () => {
                        API.destroy({ ids: row.id }).then(res => {
                          if (res.code == 0) {
                            this.$Message.success('删除成功');
                            this.request();
                          }
                        });
                      }
                    });
                  }
                }
              }, '删除'));
            }

            if (this.haveJurisdiction(row.status == 1 ? 'disable' : 'enable')) {
              html.push(h('Button', {
                props: {
                  type: row.status == 1 ? 'default' : 'warning',
                  size: 'small',
                  disabled: false,
                  icon: row.status == 1 ? 'md-remove-circle' : 'md-checkbox-outline'
                },
                class: ['btn'],
                on: {
                  click: () => {
                    let data = {
                      status: row.status == 1 ? 2 : 1
                    };
                    API.update(data, row.id).then(res => {
                      if (res.code == 0) {
                        this.$Message.success('状态更新成功');
                        this.$set(row, 'status', data.status);
                      }
                    });
                  }
                }
              }, row.status == 1 ? '禁用' : '启用'));
            }

            if (html.length) {
              return h('div', html);
            }
          }
        }
      ]
    };
  },
  created() {
    this.index(1);
  },
  methods: {
    /**
       * [index 列表]
       * @param  {Number} page [description]
       * @return {[type]}      [description]
       */
    index(page = 1) {
      let data = this.searchDataHandle(this.params, { page }, { with: 'roles' });
      this.isShowLoading(true);
      API.index(data).then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.list_data = res.data;
        }
      }).catch(err => {
        this.isShowLoading(false);
      });
    },

    /**
       * [openEdit 打开编辑弹窗]
       * @return {[type]} [description]
       */
    openEdit(bool, data = null) {
      this.editObj = {
        show: bool,
        data
      };
    },

    /**
       * [request 刷新]
       * @return {[type]} [description]
       */
    request() {
      const result = this.list_data;
      let page = result.current_page;

      if (this.list_data.data.length == 1) {
        page = this.returnPage(result.total, result.current_page, result.per_page);
      }

      this.index(page);
    },

    resetSearch() {
      for (let k in this.params) {
        this.params[k] = '';
      }
      this.index(1);
    }
  }
};
