import * as API from 'api/base/roles';

export default{
  name: 'Roles',
  components: {
    UiEdit: resolve => require(['views/user/roles/edit'], resolve),
    UiDetail: resolve => require(['views/user/roles/detail'], resolve),
    UiPermissions: resolve => require(['views/user/roles/permissions'], resolve)
  },
  data() {
    return {
      params: {
        name: ''
      },
      table_titles: [
        {
          title: '角色名',
          key: 'name'
        },
        {
          title: '创建时间',
          key: 'created_at',
          width: 170
        },
        {
          title: '更新时间',
          key: 'updated_at',
          width: 170
        },
        {
          title: '操作',
          key: 'action',
          width: 315,
          render: (h, { row, column, index }) => {
            let html = [];

            if (this.haveJurisdiction('show')) {
              html.push(h('Button', {
                props: {
                  type: 'success',
                  size: 'small',
                  disabled: false,
                  icon: 'md-eye'
                },
                class: ['btn'],
                on: {
                  click: (event) => {
                    this.detailObj = {
                      show: true,
                      data: row
                    };
                  }
                }
              }, '查看'));
            }

            if (this.haveJurisdiction('update')) {
              html.push(h('Button', {
                props: {
                  type: 'primary',
                  size: 'small',
                  disabled: false,
                  icon: 'md-create'
                },
                class: ['btn'],
                on: {
                  click: (event) => {
                    this.openEdit(true, row);
                  }
                }
              }, '编辑'));
            }

            if (this.haveJurisdiction('destroy')) {
              html.push(h('Button', {
                props: {
                  type: 'error',
                  size: 'small',
                  disabled: false,
                  icon: 'md-trash'
                },
                class: ['btn'],
                on: {
                  click: () => {
                    this.$Modal.confirm({
                      title: '提示',
                      content: '确认删除此角色？',
                      onOk: () => {
                        API.destroy({ ids: row.id }).then(res => {
                          if (res.code == 0) {
                            this.$Message.success('删除成功');
                            this.request();
                          }
                        });
                      }
                    });
                  }
                }
              }, '删除'));
            }

            if (this.haveJurisdiction('jurisdiction')) {
              html.push(h('Button', {
                props: {
                  type: 'warning',
                  size: 'small',
                  disabled: false,
                  icon: 'md-git-compare'
                },
                class: ['btn'],
                on: {
                  click: () => {
                    this.permissionsObj = {
                      show: true,
                      data: row
                    };
                  }
                }
              }, '分配权限'));
            }

            if (html.length) {
              return h('div', html);
            }
          }
        }
      ],
      list_data: null,
      editObj: {
        show: false,
        data: null
      },
      permissionsObj: {
        show: false,
        data: null
      },
      detailObj: {
        show: false,
        data: null
      },
      search: {
        show: false
      }
    };
  },
  created() {
    this.index(1);
  },
  methods: {
    /**
       * [index 列表]
       * @param  {Number} page [description]
       * @return {[type]}      [description]
       */
    index(page = 1) {
      let data = this.searchDataHandle(this.params, { page });
      this.isShowLoading(true);
      API.index(data).then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.list_data = res.data;
        }
      }).catch(err => {
        this.isShowLoading(false);
      });
    },

    /**
       * [openEdit 打开编辑弹窗]
       * @return {[type]} [description]
       */
    openEdit(bool, data = null) {
      this.editObj = {
        show: bool,
        data
      };
    },

    /**
       * [request 刷新]
       * @return {[type]} [description]
       */
    request() {
      const result = this.list_data.roles;
      let page = result.current_page;

      if (result.data.length == 1) {
        page = this.returnPage(result.total, result.current_page, result.per_page);
      }

      this.index(page);
    },

    resetSearch() {
      for (let k in this.params) {
        this.params[k] = '';
      }
      this.index(1);
    }
  }
};
