import * as API from 'api/base/roles';
import {
  index
} from 'api/base/permissions';

export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    data: {
      type: Object,
      default() {
        return null;
      }
    }
  },
  watch: {
    show(bool) {
      this.my_show = bool;
      if (bool) {
        this.account_permissions_count = 0;
        this.getPermissions();
      }
    }
  },
  data() {
    return {
      loading: false,
      my_show: false,
      account_permissions: [], // 所有权限
      account_permissions_count: 0, // 权限个数
      list: [], // tree数据
      checked: [], // 选中节点数组
      check_all: false,
      params: {
        permission_ids: []
      }
    };
  },
  methods: {
    ok() {
      this.params.permission_ids = [];
      this.moreID(this.account_permissions, this.checked, []);

      let data = {
        role_id: this.data.id,
        permission_ids: this.params.permission_ids.join(',')
      };

      this.loading = true;
      API.syncPermissions(data).then(res => {
        this.loading = false;
        if (res.code == 0) {
          this.$Message.success('修改成功');
          this.my_show = false;
        }
      }).catch(err => {
        this.loading = false;
      });
    },

    /**
     * [getPermissions 获取所有权限]
     * @return {[type]} [description]
     */
    getPermissions() {
      this.isShowLoading(true);
      index().then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.account_permissions = res.data;
          if (this.data && this.data.id) {
            this.detail(this.data.id);
          }
        }
      }).catch(err => {
        this.isShowLoading(false);
      });
    },

    /**
     * [show 详情]
     * @param  {[type]} id [description]
     * @return {[type]}    [description]
     */
    detail(id) {
      this.isShowLoading(true);
      API.show(id).then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.params.permission_ids = [];
          const cur_permissionsIDs = this.getRolesPermissions(res.data.permissions, []);
          this.reduceID(this.account_permissions, cur_permissionsIDs);
          this.setData(this.params.permission_ids);

          this.$nextTick(() => {
            this.checked = this.$refs.tree.getCheckedNodes();
          });

          if (cur_permissionsIDs.length == this.account_permissions_count) {
            this.check_all = true;
          } else {
            this.check_all = false;
          }
        }
      }).catch(err => {
        this.isShowLoading(false);
      });
    },

    /**
     * [getRolesPermissions 获取当前角色权限id]
     * @return {[type]} [description]
     */
    getRolesPermissions(data, array = []) {
      data.forEach(item => {
        array.push(item.id);
        if (item.children && item.children.length) {
          this.getRolesPermissions(item.children, array);
        }
      });
      return array;
    },

    /**
     * [setData 获取所有权限]
     * @param {[type]} ids [当前角色权限id数组]
     */
    setData(ids) {
      const data = this.handle(this.account_permissions, ids);
      // console.log(data);
      this.list = (data && data.length) ? data : [];
    },

    /**
     * [handle 处理权限数据]
     * @param  {[type]} data  [处理的数据]
     * @param  {[type]} array [处理后的数据]
     * @param  {[type]} ids   [当前角色权限id数组]
     * @param  {[type]} index [description]
     * @return {[type]}       [description]
     */
    handle(data, ids) {
      let array = [];
      data.forEach((item, i) => {
        this.account_permissions_count++;
        let obj = {
          id: item.id,
          parent_id: item.parent_id,
          title: item.title,
          expand: true,
          checked: ids.includes(item.id),
          selected: false,
          children: [],
          disabled: !item.status
        };

        if (item.children && item.children.length) {
          obj.children = this.handle(item.children, ids);
        }

        array.push(obj);
      });

      return array;
    },

    /**
     * [handleCheck 全选/反选数据处理]
     * @param  {[type]} data [数组]
     * @param  {[type]} bool [选中、不选中]
     * @return {[type]}      [description]
     */
    handleCheck(data, bool) {
      data.forEach(item => {
        this.$set(item, 'checked', bool);
        if (item.children && item.children.length) {
          this.handleCheck(item.children, bool);
        }
      });
    },

    /**
     * [checkChanges 全选/反选]
     * @return {[type]} [description]
     */
    checkChanges() {
      this.$nextTick(() => {
        this.check_all = !this.check_all;
        this.handleCheck(this.list, this.check_all);
        this.checked = this.$refs.tree.getCheckedNodes();
        this.$forceUpdate();
      });
    },

    checkChange(data) {
      this.$nextTick(() => {
        // console.log(data);
        this.checked = data;
        if (data.length == this.account_permissions_count) {
          this.check_all = true;
        } else {
          this.check_all = false;
        }
      });
    },

    visibleChange(bool) {
      if (!bool) {
        this.check_all = false;
        this.$emit('update:show', false);

        // this.list = [];

        // 取消树所有选中状态
        this.check_all = true;
        this.checkChanges();
      }
    },

    /**
     * [moreID 处理权限ids数据，提交时，需要获取到勾选数据所有上级]
     * @param  {[type]} permissions [description]
     * @param  {[type]} data        [description]
     * @param  {Array}  parent_id   [description]
     * @return {[type]}             [description]
     */
    moreID(permissions, data, parent_id = []) {
      for (let i = 0, len = permissions.length; i < len; i++) {
        const id = permissions[i].id;
        const pid = permissions[i].parent_id;

        if (!pid) parent_id = [];

        for (let j = 0, len2 = data.length; j < len2; j++) {
          let item = data[j];

          if (id == item.id) {
            this.params.permission_ids.push(id);

            // 最后一级
            if (!(Object.prototype.toString.call(permissions[i].children) == '[object Array]' && permissions[i].children.length)) {
              parent_id.forEach(temp_id => {
                if (this.params.permission_ids.indexOf(temp_id) == -1) {
                  this.params.permission_ids.push(temp_id);
                }
              });
            }
            break;
          }

          if (j == len2 - 1 && i == len - 1) {
            // 当遍历到最后一个元素,还没找到相等的id且没有下级元素，去除最后一个parent_id
            if (!(Object.prototype.toString.call(permissions[i].children) == '[object Array]' && permissions[i].children.length)) {
              parent_id.pop();
            }
          }
        }

        if (Object.prototype.toString.call(permissions[i].children) == '[object Array]' && permissions[i].children.length) {
          parent_id.push(id);
          this.moreID(permissions[i].children, data, parent_id);
        }
      }
    },

    /**
     * [reduceID]
     * @param  {[type]} permissions [description]
     * @param  {[type]} data        [description]
     * @return {[type]}             [description]
     */
    reduceID(permissions, data) {
      let count = 0;
      let pid;
      for (let i = 0, len = permissions.length; i < len; i++) {
        pid = permissions[i].parent_id;
        data.forEach((id, index) => {
          if (permissions[i].id == id) {
            if (!(Object.prototype.toString.call(permissions[i].children) == '[object Array]' && permissions[i].children.length)) {
              count++;
              this.params.permission_ids.push(id);
            }
          }
        });

        if (Object.prototype.toString.call(permissions[i].children) == '[object Array]' && permissions[i].children.length) {
          this.reduceID(permissions[i].children, data);
        }
      }
      if (count > 0 && count == permissions.length && pid) {
        this.params.permission_ids.push(pid);
      }
    }
  }
};
