import * as API from 'api/virtual/flow_pools';

export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    month: {
      type: String,
      default: false
    },
    data: {
      type: Object,
      default() {
        return null;
      }
    }
  },
  watch: {
    show(bool) {
      this.my_show = bool;

      if (bool) {
        this.index(1);
      }
    }
  },
  data() {
    return {
      limit: 5,
      my_show: false,
      flowPool: null,
      cards: null,
      packages: [],
      renewPackages: [],
      cardsColumns: [{
        title: 'SIM',
        key: 'sim'
      },
      {
        title: '套餐名称',
        key: 'package_name'
      },
      {
        title: '保底流量',
        key: 'minimum_flows'
      },
      {
        title: '已用流量',
        key: 'mebibyte'
      }
      ]
    };
  },
  methods: {
    /**
     * [index 列表]
     * @param  {Number} page [description]
     * @return {[type]}      [description]
     */
    index(page) {
      this.isShowLoading(true);
      let params = {
        'pool_id': this.data.id,
        'month': this.month,
        'page': page,
        'limit': this.limit
      };

      API.show({
        params
      }).then(res => {
        this.isShowLoading(false);
        if (res.code == 0) {
          this.flowPool = res.data.flowPool;
          this.cards = res.data.cards;
          this.packages = this.flowPool.packages.filter(item => {
            return item.type === 0;
          });
          this.renewPackages = this.flowPool.packages.filter(item => {
            return item.type === 2;
          });

          this.flowPool.settings.map(setting => {
            setting.gradient_price = Number(setting.gradient_price);
            setting.gradient = Number(setting.gradient);
            setting.minimum_settings.map(item => {
              item.price = Number(item.price);
              item.flow = Number(item.flow);
            });
          });
        }
      }).catch(() => {
        this.isShowLoading(false);
      });
    },
    visibleChange(bool) {
      this.$emit('update:show', bool);
    },
    changeLimit(limit) {
      this.limit = limit;
      this.index(1);
    },
    exportExcel() {
      let params = {
        'pool_id': this.data.id,
        'month': this.month
      };

      this.isShowLoading(true);

      API.exportDetail(params).then(res => {
        if (res.code === 0) {
          if (res.data) {
            this.downloadFile(res.data);
          } else {
            this.$Modal.success({
              title: '提示',
              content: '当前导出数据量大，已进入后台队列导出模式，请稍后至导出列表查看下载。'
            });
          }
        }
        this.isShowLoading(false);
      }).catch(() => {
        this.isShowLoading(false);
      });
    }
  }
};
