import * as API from "api/virtual/flow_pools";
import { sumBy } from "service/util";

export default {
  name: "FlowPools",
  components: {
    UiEdit: resolve => require(["views/virtual/flow_pools/edit"], resolve),
    UiDetail: resolve => require(["views/virtual/flow_pools/detail"], resolve),
    UiSetting: resolve =>
      require(["views/virtual/flow_pools/setting"], resolve),
    UiFlows: resolve => require(["views/virtual/flow_pools/flows"], resolve)
  },
  data() {
    return {
      limit: 10,
      options: {
        company_name: "",
        name: "",
        carrier_operator: "",
        month: this.moment()
          .subtract("1", "months")
          .startOf("month")
          .format("YYYY-MM")
      },
      list_data: null,
      reals: [],
      editObj: {
        show: false,
        data: null
      },
      settingObj: {
        show: false,
        data: null
      },
      detailObj: {
        show: false,
        data: null
      },
      flowsObj: {
        show: false,
        pool_id: 0
      },
      search: {
        show: true
      },
      importModel: false,
      table_titles: [
        {
          title: "ID",
          key: "id",
          width: 75
        },
        {
          title: "名称",
          key: "",
          width: 135,
          render: (h, { row, column, index }) => {
            if (this.list_data && index == this.list_data.data.length - 1) {
              return;
            }

            if (row.setting_status) {
              return h("span", row.name);
            }

            return h(
              "Tooltip",
              {
                props: {
                  theme: "light"
                }
              },
              [
                h("Badge", {
                  props: {
                    status: "error"
                  }
                }),
                h("span", row.name),
                h(
                  "div",
                  {
                    slot: "content"
                  },
                  [
                    h("p", "当前月份计费规则未设置"),
                    h("p", "或套餐保底流量未设置")
                  ]
                )
              ]
            );
          }
        },
        {
          title: "运营商",
          key: "carrier_operator_name",
          width: 80
        },
        {
          title: "客户名称",
          key: "company_name",
          width: 300
        },
        {
          title: "保底流量",
          key: "minimum_flows",
          width: 150
        },
        {
          title: "超出流量",
          key: "excess_flows",
          width: 150
        },
        {
          title: "保底收入(元)",
          key: "minimum_price",
          width: 150
        },
        {
          title: "超出收入(元)",
          key: "excess_price",
          width: 150
        },
        {
          title: "收费用户数",
          key: "members",
          width: 110
        },
        {
          title: "总收入(元)",
          key: "total_price",
          width: 150
        },
        {
          title: "状态",
          key: "",
          width: 100,
          render: (h, { row, column, index }) => {
            if (this.list_data && index == this.list_data.data.length - 1) {
              return;
            }

            return h(
              "Tag",
              {
                props: {
                  color: row.status ? "error" : "primary"
                }
              },
              row.status ? "已禁用" : "启用中"
            );
          }
        },
        {
          title: "更新时间",
          key: "created_at",
          width: 170
        },
        {
          title: "操作",
          key: "action",
          width: 450,
          render: (h, { row, column, index }) => {
            if (this.list_data && index == this.list_data.data.length - 1) {
              return;
            }

            let html = [];

            if (row.deleted_at) {
              return h(
                "Tag",
                {
                  props: {
                    color: "default"
                  }
                },
                "该流量池已被删除"
              );
            }

            if (this.haveJurisdiction("show")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "success",
                      size: "small",
                      disabled: false,
                      icon: "md-eye"
                    },
                    class: ["btn"],
                    on: {
                      click: event => {
                        this.detailObj = {
                          show: true,
                          data: row
                        };
                      }
                    }
                  },
                  "查看"
                )
              );
            }

            if (this.haveJurisdiction("update")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "primary",
                      size: "small",
                      disabled: false,
                      icon: "md-create"
                    },
                    class: ["btn"],
                    on: {
                      click: event => {
                        this.openEdit(true, row);
                      }
                    }
                  },
                  "编辑"
                )
              );
            }

            if (this.haveJurisdiction("update")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "info",
                      size: "small",
                      disabled: false,
                      icon: "md-card"
                    },
                    class: ["btn"],
                    on: {
                      click: event => {
                        this.openFlows(true, row);
                      }
                    }
                  },
                  "数据设置"
                )
              );
            }

            if (this.haveJurisdiction("update")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "warning",
                      size: "small",
                      disabled: false,
                      icon: "logo-yen"
                    },
                    class: ["btn"],
                    on: {
                      click: event => {
                        this.openSetting(true, row);
                      }
                    }
                  },
                  "计费规则"
                )
              );
            }

            if (this.haveJurisdiction("destroy")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "error",
                      size: "small",
                      disabled: false,
                      icon: "md-trash"
                    },
                    class: ["btn"],
                    on: {
                      click: () => {
                        this.$Modal.confirm({
                          title: "提示",
                          content: "删除后该流量池不可使用，请谨慎操作",
                          onOk: () => {
                            API.destroy({
                              ids: row.id
                            }).then(res => {
                              if (res.code == 0) {
                                this.$Message.success("删除成功");
                                this.request();
                              }
                            });
                          }
                        });
                      }
                    }
                  },
                  "删除"
                )
              );
            }

            if (html.length) {
              return h("div", html);
            }
          }
        }
      ]
    };
  },
  created() {
    this.index(1);
  },
  methods: {
    /**
     * [index 列表]
     * @param  {Number} page [description]
     * @return {[type]}      [description]
     */
    index(page = 1) {
      let data = this.searchDataHandle(
        {},
        {
          page,
          limit: this.limit
        },
        this.params()
      );
      this.isShowLoading(true);
      API.index(data)
        .then(res => {
          this.isShowLoading(false);
          if (res.code == 0) {
            let list_data = res.data;

            let array = list_data.data;

            array.push({
              id: '总计',
              members: sumBy(list_data.data, "members"),
              total_price: sumBy(list_data.data, "total_price")
            });

            list_data.data = array;

            this.list_data = list_data;
          }
        })
        .catch(() => {
          this.isShowLoading(false);
        });
    },
    changeLimit(limit) {
      this.limit = limit;
      this.index();
    },
    params() {
      if (!this.options.month) {
        this.options.month = this.moment()
          .subtract("1", "months")
          .startOf("month")
          .format("YYYY-MM");
      }

      let params = {
        name: this.options.name,
        company_name: this.options.company_name,
        carrier_operator: this.options.carrier_operator,
        month: this.moment(this.options.month).format("YYYY-MM"),
        orderBy: "id",
        sortedBy: "asc"
      };

      return params;
    },

    /**
     * [openEdit 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openEdit(bool, data = null) {
      this.editObj = {
        show: bool,
        data
      };
    },

    /**
     * [openSetting 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openSetting(bool, data = null) {
      this.settingObj = {
        show: bool,
        data: data
      };
    },

    /**
     * [openFlows 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openFlows(bool, data = null) {
      this.flowsObj = {
        show: bool,
        pool_id: data.id
      };
    },

    /**
     * [request 刷新]
     * @return {[type]} [description]
     */
    request() {
      const result = this.list_data;
      let page = result.current_page;

      if (this.list_data.data.length == 1) {
        page = this.returnPage(
          result.total,
          result.current_page,
          result.per_page
        );
      }

      this.index(page);
    },

    resetSearch() {
      for (let k in this.options) {
        if (k === "month") {
          this.options[k] = this.moment()
            .subtract("1", "months")
            .startOf("month")
            .format("YYYY-MM");
        } else {
          this.options[k] = "";
        }
      }

      this.index(1);
    },
    exportExcel() {
      let data = this.searchDataHandle({}, { limit: 0 }, this.params());

      this.isShowLoading(true);

      API.exportList(data)
        .then(res => {
          if (res.code === 0) {
            if (res.data) {
              this.downloadFile(res.data);
            } else {
              this.$Modal.success({
                title: "提示",
                content:
                  "当前导出数据量大，已进入后台队列导出模式，请稍后至导出列表查看下载。"
              });
            }
          }

          this.isShowLoading(false);
        })
        .catch(() => {
          this.isShowLoading(false);
        });
    },
    importFlows(file) {
      this.isShowLoading(true);
      API.importFlows(file).then(res => {
        if (res.code === 0) {
          this.request();
          this.$Message.success(res.message);
          this.importModel = false;
        }

        this.isShowLoading(false);
      });

      return false;
    }
  }
};
