import * as API from 'api/virtual/flow_pools';

export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    data: {
      type: Object,
      default: null
    }
  },
  data() {
    return {
      my_show: false,
      loading: false,
      settings: [],
      params: {},
      start_at: this.moment('2000-01-01 00:00:00').format('YYYY-MM'),
      end_at: this.moment('3000-01-01 23:59:59').format('YYYY-MM'),
      monthOptions: {
        shortcuts: [{
          text: '最早',
          value: () => {
            return this.start_at;
          }
        },
        {
          text: '至今',
          value: () => {
            return this.end_at;
          }
        },
        {
          text: '上月',
          value: () => {
            return this.moment().subtract('1', 'months').format('YYYY-MM');
          }
        }
        ],
        disabledDate(date) {
          return date && (date.valueOf() < this.start_at || date.valueOf() > this.end_at);
        }
      }
    };
  },
  watch: {
    show(bool) {
      this.my_show = bool;
      if (bool) {
        this.settings = this.data.settings;
        if (this.data.settings.length) {
          this.set(this.data.settings[0]['id']);
        } else {
          this.set(0);
        }
      }
    }
  },
  methods: {
    ok() {
      if (this.params.pool_id === '') {
        this.$Message.info('参数错误');
        return;
      }

      if (this.params.start_at === '') {
        this.$Message.info('请选择开始时间');
        return;
      }

      if (this.params.end_at === '') {
        this.$Message.info('请选择结束时间');
        return;
      }

      if (this.params.gradient < 1) {
        this.$Message.info('梯度必须大于等于1');
        return;
      }

      if (this.params.gradient_unit === '') {
        this.$Message.info('请选择梯度单位');
        return;
      }

      for (const key in this.params.minimum_settings) {
        let minimum_setting = this.params.minimum_settings[key];

        if (minimum_setting.flows === 0 && minimum_setting.price) {
          this.$Message.info('保底流量配置不正确');
          return;
        }
      }

      this.params.start_at = this.moment(this.params.start_at).format('YYYY-MM');
      this.params.end_at = this.moment(this.params.end_at).format('YYYY-MM');

      if (this.params.id) {
        // 编辑
        API.setting(this.params).then(res => {
          this.loading = false;
          if (res.code == 0) {
            this.$emit('update-success');
            this.$Message.success('更新成功');
            this.clear();
          }
        }).catch(err => {
          this.loading = false;
        });
      } else {
        // 添加
        API.setting(this.params).then(res => {
          this.loading = false;
          if (res.code == 0) {
            this.$emit('add-success');
            this.$Message.success('添加成功');
            this.clear();
          }
        }).catch(err => {
          this.loading = false;
        });
      }
    },

    visibleChange(bool) {
      if (!bool) {
        this.$emit('update:show', false);
      }
    },
    clear() {
      this.params = {};

      this.my_show = false;
    },
    set(id) {
      if (id) {
        this.params = this.settings.filter(item => {
          return item.id == id;
        })[0];

        this.params.id = id;
      } else {
        let minimum_settings = [];

        this.data.packages.map(item => {
          minimum_settings.push({
            package_id: item.package_id,
            package_name: item.package_name,
            flows: 0,
            price: 0
          });
        });

        this.params = {
          pool_id: this.data.id,
          start_at: this.data.settings.length ? this.moment().subtract('1', 'months').format('YYYY-MM') : this.start_at,
          end_at: this.data.settings.length ? this.moment().subtract('1', 'months').format('YYYY-MM') : this.end_at,
          gradient_price: 0,
          gradient: 0,
          gradient_unit: 0,
          minimum_settings: minimum_settings
        };
      }

      this.params.gradient_price = Number(this.params.gradient_price);
      this.params.gradient = Number(this.params.gradient);
      this.params.minimum_settings.map(item => {
        item.price = Number(item.price);
        item.flows = Number(item.flows);
      });
    }
  }
};
