import * as API from "api/virtual/products";

export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    type: {
      type: Number,
      default: 0
    },
    isUpdate: {
      type: Boolean,
      default: false
    },
    data: {
      type: Object,
      default() {
        return null;
      }
    }
  },
  data() {
    return {
      my_show: false,
      loading: false,
      params: {
        type: 0,
        name: "",
        company_id: "",
        package_id: "",
        price: 0,
        renew_price: 0,
        remark: "",
        status: 0
      },
      completePackagesFilter: []
    };
  },
  watch: {
    show(bool) {
      this.my_show = bool;
      if (bool) {
        if (this.data) {
          for (let k in this.data) {
            if (k in this.params) {
              this.params[k] = this.data[k];
            }
          }
        }
      }

      this.initCompletePackages(this.type).then(packages => {
        this.completePackagesFilter = packages.filter(function(item) {
          return item.status === 0;
        });
      });
    }
  },
  methods: {
    ok() {
      if (!this.params.company_id) {
        this.$Message.info("非法请求");
      }

      if (!this.params.name) {
        this.$Message.info("请输入定价名称");
        return;
      }

      if (!this.params.package_id) {
        this.$Message.info("请选择一个套餐");
        return;
      }

      if (this.params.price === null) {
        this.$Message.info("请输入销售价格");
        return;
      }

      if (this.params.renew_price === null) {
        this.$Message.info("请输入续费价格");
        return;
      }

      this.params.type = this.type;

      if (this.isUpdate) {
        // 编辑
        API.update(this.params, this.data.id)
          .then(res => {
            this.loading = false;
            if (res.code == 0) {
              this.$emit("update-success");
              this.$Message.success("更新成功");
              this.clear();
            }
          })
          .catch(err => {
            this.loading = false;
          });
      } else {
        // 添加
        API.create(this.params)
          .then(res => {
            this.loading = false;
            if (res.code == 0) {
              this.$emit("add-success");
              this.$Message.success("添加成功");
              this.clear();
            }
          })
          .catch(err => {
            this.loading = false;
          });
      }
    },

    visibleChange(bool) {
      if (!bool) {
        this.$emit("update:show", false);
      }
    },
    clear() {
      for (let k in this.params) {
        if (k === "price" || k === "status" || k === "renew_price") {
          this.params[k] = 0;
        } else {
          this.params[k] = "";
        }
      }

      this.my_show = false;
    }
  }
};
