import * as API from "api/virtual/products";

export default {
  name: "Products",
  components: {
    UiEdit: resolve => require(["views/virtual/products/edit"], resolve),
    UiHistory: resolve => require(["views/virtual/products/history"], resolve)
  },
  data() {
    return {
      params: {
        company_id: "",
        carrier_operator: "",
        name: "",
        package_name: "",
        status: ""
      },
      editObj: {
        show: false,
        isUpdate: false,
        data: null
      },
      historyObj: {
        show: false,
        data: null
      },
      search: {
        show: false
      },
      inputValue: "",
      companies: [],
      company: { id: 0, name: "请选择企业" },
      data: [],
      columns: [
        {
          title: "序号",
          key: "",
          width: 80,
          render: (h, context) => {
            return h("span", context.row._index + 1);
          }
        },
        {
          title: "定价名称",
          key: "name",
          width: 150
        },
        {
          title: "套餐名称",
          key: "",
          width: 120,
          render: (h, { row, column, index }) => {
            if (row.package) {
              return h("span", row.package.name);
            }
          }
        },
        {
          title: "销售价格",
          key: "price",
          width: 100,
          render: (h, { row, column, index }) => {
            return h("span", Number(row.price).toFixed(2));
          }
        },
        {
          title: "运营商",
          key: "carrier_operator_name",
          width: 100
        },
        {
          title: "备注",
          key: "remark",
          minWidth: 150,
          tooltip: true
        },
        {
          title: "状态",
          key: "",
          width: 100,
          render: (h, { row, column, index }) => {
            let type = ["primary", "warning", "error"];
            let text = ["已启用", "已禁用", "已删除"];

            return h(
              "Button",
              {
                props: {
                  type: type[row.status],
                  size: "small"
                }
              },
              text[row.status]
            );
          }
        },
        {
          title: "创建时间",
          key: "created_at",
          width: 170
        },
        {
          title: "更新时间",
          key: "updated_at",
          width: 170
        },
        {
          title: "操作",
          key: "action",
          width: 170,
          render: (h, { row, column, index }) => {
            if (row.deleted_at) {
              return h(
                "Tag",
                { props: { color: "default" } },
                "该定价已被删除"
              );
            }

            row.price = Number(row.price);
            row.renew_price = Number(row.renew_price);

            let html = [];

            html.push(
              h(
                "Button",
                {
                  props: {
                    type: "success",
                    size: "small",
                    disabled: false,
                    icon: "md-list"
                  },
                  class: ["btn"],
                  on: {
                    click: event => {
                      this.openHistory(true, row);
                    }
                  }
                },
                "历史"
              )
            );

            if (this.haveJurisdiction("update")) {
              html.push(
                h(
                  "Button",
                  {
                    props: {
                      type: "primary",
                      size: "small",
                      disabled: false,
                      icon: "md-create"
                    },
                    class: ["btn"],
                    on: {
                      click: event => {
                        this.openEdit(true, row);
                      }
                    }
                  },
                  "编辑"
                )
              );
            }

            /**
            if (this.haveJurisdiction('destroy')) {
              html.push(h('Button', {
                props: {
                  type: 'error',
                  size: 'small',
                  disabled: false,
                  icon: 'md-trash'
                },
                class: ['btn'],
                on: {
                  click: () => {
                    this.$Modal.confirm({
                      title: '提示',
                      content: '删除后该定价不可使用，请谨慎操作',
                      onOk: () => {
                        API.destroy({
                          ids: row.id
                        }).then(res => {
                          if (res.code == 0) {
                            this.$Message.success('删除成功');
                            this.request();
                          }
                        });
                      }
                    });
                  }
                }
              }, '删除'));
            }
            */

            if (html.length) {
              return h("div", html);
            }
          }
        }
      ]
    };
  },
  watch: {
    inputValue(value) {
      this.handleCompleteCompanies(value).then(res => {
        this.companies = res.filter(item => {
          return item.status === 0;
        });
      });
    }
  },
  created() {
    this.type = Number(this.$route.params.type);

    this.initCompleteCompanies().then(res => {
      this.companies = res.filter(function(item) {
        return item.status === 0;
      });
    });
  },
  methods: {
    /**
     * [index 列表]
     * @param  {Number} company_id [description]
     * @return {[type]}      [description]
     */
    index(company_id = null) {
      this.params.type = this.type;

      if (company_id) {
        this.params.company_id = company_id;
        this.company = this.companies.find(item => {
          return item.id === company_id;
        });
      }

      this.isShowLoading(true);

      let params = this.searchDataHandle({}, {}, this.params);

      if (params.status === 2) {
        params.status = undefined;
        params.trashed = "only";
      } else {
        params.trashed = "without";
      }

      if (params.type == 3) {
        params.type = [3, 4, 5];
      }

      API.index(params)
        .then(res => {
          this.isShowLoading(false);
          if (res.code == 0) {
            this.data = res.data;
          }
        })
        .catch(() => {
          this.isShowLoading(false);
        });
    },

    /**
     * [openEdit 打开编辑弹窗]
     * @return {[type]} [description]
     */
    openEdit(show, row = null) {
      let isUpdate = false;
      let data = {};

      if (row) {
        isUpdate = true;
        data = JSON.parse(JSON.stringify(row));
        data.price = data.price ? data.price : 0;
        data.company_id = this.params.company_id;
      } else {
        data = { company_id: this.params.company_id };
      }

      this.editObj = { show, data, isUpdate };
    },

    /**
     * [openHistory 打开历史弹窗]
     * @return {[type]} [description]
     */
    openHistory(show, row) {
      this.historyObj = { show, data: row };
    },
    /**
     * [request 刷新]
     * @return {[type]} [description]
     */
    request() {
      this.index();
    },
    resetSearch() {
      for (let k in this.params) {
        if (k !== "company_id") {
          this.params[k] = "";
        }
      }
      this.index();
    },
    handleSearchPackages(value) {
      this.params.package_id = value;
    }
  }
};
