<?php

namespace Dipper\Console\Commands;

use Exception;
use Illuminate\Support\Str;
use Dipper\Console\Generators\ModelGenerator;
use Symfony\Component\Console\Input\InputArgument;

/**
 * Class ModelMakeCommand.
 *
 * @author HollyTeng <n.haoyuan@gmail.com>
 */
class ModelMakeCommand extends GeneratorCommand
{
    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'make:model';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create a new Eloquent Model.';

    /**
     * The type of class being generated.
     * @var string
     */
    protected $type = 'Model';

    /**
     * Get the stub file for the generator.
     *
     * @return string
     */
    public function getStub()
    {
        return __DIR__ . '/stubs/model.stub';
    }

    /**
     * Replace the class name for the given stub.
     *
     * @param  string  $stub
     * @param  string  $name
     * @return string
     */
    protected function replaceClass($stub, $name, $domain = null, $use = null)
    {
        $classname = str_replace($this->getNamespace($name).'\\', '', $name);
        $class = Str::replaceLast($classname, $this->type, '');
        $tableName = str_plural(Str::snake($classname));

        return str_replace(
            ['{{classname}}', '{{class}}', '{{table_name}}'],
            [ $classname,  $class, $tableName],
            $stub
        );
    }

    public function getArguments()
    {
        return [
            ['name', InputArgument::REQUIRED, 'The name of the class'],
        ];
    }
}
