<?php

namespace Dipper\Foundation\Core;

use Dipper\Foundation\Database\Paginator;
use Illuminate\Database\Eloquent\Model as Eloquent;

/**
 * Base Model.
 */
abstract class Model extends Eloquent
{
    protected $guarded = [];

    /**
     * Cast an attribute to a native PHP type.
     *
     * @param  string  $key
     * @param  mixed  $value
     * @return mixed
     */
    protected function castAttribute($key, $value)
    {
        $value = parent::castAttribute($key, $value);

        if (is_numeric($value) && $value > 4294967295) {
            return (string) $value;
        }

        return $value;
    }

    /**
     * Encode the given value as JSON.
     *
     * @param  mixed  $value
     * @return string
     */
    protected function asJson($value)
    {
        return json_encode($value, 256);
    }
}
