<?php

namespace Dipper\Foundation\Repository;

use Closure;
use Illuminate\Database\Query\Builder;
use Illuminate\Contracts\Cache\Repository as CacheRepository;

/**
 * Interface CacheableInterface.
 */
interface CacheableInterface
{
    /**
     * Set Cache Repository.
     *
     * @param CacheRepository $repository
     *
     * @return $this
     */
    public function setCacheRepository(CacheRepository $repository);

    /**
     * Return instance of Cache Repository.
     *
     * @return CacheRepository
     */
    public function getCacheRepository();

    /**
     * Clean cache.
     *
     * @return void
     */
    public function forgetCached();

    /**
     * Get Cache key for the method.
     *
     * @param $method
     * @param $args
     *
     * @return string
     */
    public function getCacheKey($query);

    /**
     * Get cache minutes.
     *
     * @return int
     */
    public function getCacheMinutes();

    /**
     * Skip Cache.
     *
     * @param bool $status
     *
     * @return $this
     */
    public function skipCache($status = true);

    /**
     * Remember Cache
     *
     * @param string $method
     * @param Builder $query
     * @param Closure $callback
     * @return void
     */
    public function rememberCache($query, Closure $callback);
}
